@@ -128,8 +128,8 @@ class ThemeMenu(QMenu):
         self.resetAction = QAction("Reset Theme")
         self.saveCurrent = QAction("Save Theme As")
         self.resetAction.triggered.connect(self.manager.reset)
-        toolbar = parent.window.styler.toolbar
-        toolbar.loadAction = self.parent().loadAction
+        # toolbar = parent.window.styler.toolbar
+        # toolbar.loadAction = self.parent().loadAction
         self.parent().loadAction.loaded.connect(self.add_new_theme)
         self.themeMenu = QMenu("Themes", parent=self)
         self.saveCurrent.triggered.connect(self.createTheme)
@@ -218,8 +218,9 @@ class FileMenu(QMenu):
     def applyStyleSheet(self):  # pragma: nocover
         """Apply theme to current app instance."""
         text = self.dialog.textEdit.toPlainText()
-        parser = QssParser(text)
-        self.parent().manager.sheets = parser.result
+        parser = QssParser()
+        parser.parse(text)
+        self.parent().manager.sheets = parser.results
         self.parent.manager.set_sheet()
         self.dialog.close()
         self.dialog.deleteLater()
