@@ -21,11 +21,13 @@
 import sys
 from typing import Optional
 
-from PySide6.QtWidgets import QMainWindow, QTabWidget, QVBoxLayout, QWidget
+from PySide6.QtWidgets import QApplication, QMainWindow, QTabWidget, QWidget
 
+from QStyler.collectionsTab import CollectionsTab
+from QStyler.editorTab import EditorsTab
 from QStyler.menubar import MenuBar
 from QStyler.styler import StylerTab
-from QStyler.utils import Application, get_icon, get_manager
+from QStyler.utils import StyleManager, get_icon, get_manager
 from QStyler.widgets import WidgetsTab
 
 
@@ -45,29 +47,44 @@ class MainWindow(QMainWindow):
         """Initialize main window."""
         super().__init__(parent=parent)
         self.setWindowTitle("QStyler")
-        self.central = QWidget(parent=self)
-        self.layout = QVBoxLayout()
-        self.central.setLayout(self.layout)
-        self.setCentralWidget(self.central)
+        self.tabWidget = QTabWidget()
+        self.setCentralWidget(self.tabWidget)
         self.setObjectName("MainWindow")
         self.resize(900, 700)
-        self.tabWidget = QTabWidget()
         self.setWindowIcon(get_icon("QStylerIcon.png"))
         self.manager = get_manager()
-        self.widgets = WidgetsTab(parent=self)
-        self.styler = StylerTab(parent=self)
-        self.tabWidget.addTab(self.styler, "Style")
-        self.tabWidget.addTab(self.widgets, "Widgets")
-        self.layout.addWidget(self.tabWidget)
         self.menubar = MenuBar(self)
         self.statusbar = self.statusBar()
-        self.styler.toolbar.activate_load_item()
         self.setMenuBar(self.menubar)
+        self.add_widgets()
+
+    def add_widgets(self):
+        """Add widgets to the main window."""
+        self.styler = StylerTab(parent=self)
+        self.widgets = WidgetsTab(parent=self)
+        self.editors = EditorsTab(parent=self)
+        self.collections = CollectionsTab(parent=self)
+        self.tabWidget.addTab(self.styler, "Style")
+        self.tabWidget.addTab(self.widgets, "Widgets")
+        self.tabWidget.addTab(self.editors, "Editors")
+        self.tabWidget.addTab(self.collections, "Collections")
+        self.styler.toolbar.activate_load_item()
+
+
+class Application(QApplication):
+    """Subclass of the QApplication."""
+
+    def __init__(self, args=None, windowclass=MainWindow):
+        """Initialize application."""
+        if not args:
+            args = sys.argv  # pragma: nocover
+        super().__init__(args)
+        self.manager = StyleManager()
+        self.window = windowclass()
 
 
 def execute():  # pragma: nocover
     """Entry point for cli and execution."""
-    app = Application(sys.argv)
-    window = MainWindow()
-    window.show()
+    app = Application(sys.argv, MainWindow)
+    app.window.show()
     sys.exit(app.exec())
